#
# spec file for package tcllib
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           tcllib
Url:            http://tcllib.sf.net
BuildRequires:  tcl
Version:        1.16
Release:        lp150.1.3
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Summary:        Tcl Standard Library
License:        TCL
Group:          Development/Libraries/Tcl
BuildRequires:  ed
Requires:       /bin/sh
BuildArch:      noarch
Source0:        %name-%version.tar.gz
Source1:        %name-rpmlintrc

%description
This package is intended to be a collection of Tcl packages that
provide utility functions useful to a large collection of Tcl
programmers.

%prep
%setup -q
# upstream typo
chmod 644 examples/mapproj/ncar780.txt

# fix DOS lineendings
ed -s modules/math/kruskal.tcl 2>/dev/null <<'EOF'
,s/
$//
w
EOF
# remove shebang from module
ed -s modules/pki/pki.tcl 2>/dev/null <<'EOF'
1g/^#!/d
w
EOF
# do not use /usr/bin/env in shebang
for script in examples/logger/logtofile.tcl examples/logger/logtotext.tcl \
        modules/stringprep/tools/gen_stringprep_data.tcl \
        examples/ldap/ldifdump modules/stringprep/tools/gen_unicode_data.tcl apps/pt apps/tcldocstrip apps/nnsd apps/nns apps/nnslog apps/dtplite apps/page; do
    ed -s "${script}" 2>/dev/null <<'EOF'
1s/^#! *\/usr\/bin\/env */#!\/usr\/bin\//
w
EOF
done

%build

%install
tclsh ./installer.tcl -no-examples -no-html \
 -app-path   %buildroot/%_bindir \
 -pkg-path   %buildroot/%_datadir/tcl/%name%version \
 -nroff-path %buildroot%_mandir/mann \
 -no-wait -no-gui

%files
%defattr(-,root,root)
%doc license.terms README ChangeLog
%doc support/releases/history/README-*
%_datadir/tcl
%_bindir/*
%doc examples
%doc %_mandir/mann/*

%changelog
* Tue Sep  2 2014 coolo@suse.com
- fix license for spdx 1.2
* Wed Feb 12 2014 kpetsch@suse.com
- Update to version 1.16.
  For details see /usr/share/doc/packages/tcllib/README-1.16.txt
* Thu Jun 20 2013 max@suse.com
- Update to version 1.15.
  For details see /usr/share/doc/packages/tcllib/README-1.13.txt
* Tue Jun  5 2012 cfarrell@suse.com
- license update: SUSE-TCL
  Make compatible with tcl license (it is the stated license of the package
  anyway)
* Tue May 29 2012 gber@opensuse.org
- Update to version 1.14
  * New module and packages:
    + oo::util: right now only easy referencing of instance methods
    for callbacks
    + lambda: easy anonymous procedures for Tcl 8.5+
    + try: Tcl 8.5+ forward compatibility implementation of
    try/catch/finally (TIP 329)
    + valtype: validation types, snit validation types for various
    classes of numbers (ISBN, EAN, ...) and general check-digit
    algorithms (luhn(5), verhoeff, ...).
  * Bufixes, for details see
    /usr/share/doc/packages/tcllib/README-1.14.txt
- fix shebang lines
- fix CRLF lineendings in modules/math/kruskal.tcl
- examples/ftp/hpupdate.tcl is under GPL-2.0+
* Wed Oct 19 2011 max@suse.com
- New version: 1.13.
- For details, see /usr/share/doc/packages/tcllib/README-1.13.txt
* Wed Jul 29 2009 max@suse.de
- New version: 1.11.1, which adds the modules cache and map.
* Fri Oct 24 2008 max@suse.de
- New version: 1.11
- Added packages and modules:
  * amazon-s3: access to amazon's S3 service
  * xsxp: XML processing helper
  * picoirc: minimal irc client
  * simulation: simulation tools
  * stringprep, unicode: preparation for internationalized strings
  * struct::disjointset: union-merge structure
  * huddle: generic serialization format
  * yaml: YAML processing
- Modules that got new features and/or bug fixes: aes, asn,
  base64, bench, blowfish, cmdline, comm, crc, dns, doctools,
  fileutil, ftp, ftpd, grammar_fa, htmlparse, http, inifile,
  jpeg, ldap, log, math, md4, md5, md5crypt, mime, nmea, nns,
  pluginmgr, sasl, term. textutil, tie, tiff, transfer, uev, wip
- Details can be found under /usr/share/doc/packages/tcllib .
* Thu Apr  3 2008 max@suse.de
- New version: 1.10
- Added modules:
  * mapproj: Map projections
  * nns: nameservice
  * uevent: user events
  * wip: word interpreter
- Modules that got new features and/or bug fixes: asn, base64,
  bench, blowfish, comm, des, dns, doctools, fileutil, ftp, ftpd,
  grammar, http, inifile, interp, ldap, log, math, mime, nmea,
  page, png, sasl, sha1, snit, struct, tar, uri.
- Details can be found under /usr/share/doc/packages/tcllib .
* Wed Oct 18 2006 tpatzig@suse.de
- New version: 1.9
- Added modules:
  base32: Base32 encoding
  bench: Benchmarking support
  interp: Interpreter utilities
  json: JavaScript Object Notation
  ldapx: OO wrapper around ldap
  math::bigfloat: Large FP numbers
  nmea: NMEA gps messages
  otp: RFC 2289 One-Time Passwd
  page: Generator for MEcpu code and graph-based compiler
  SASL::XGoogleToken: X-GOOGLE-TOKEN auth
  term: Low-level terminal control
  tiff: TIFF image manipulation
  transfer: Classes handling and organizing various types of
    data transfers across sockets.
- Textutil functionality split into separate packages.
- Updates and bugfixes to most other modules.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Dec 23 2005 max@suse.de
- New version: 1.8
* Tue Jun 14 2005 max@suse.de
- Moved to /usr/share/tcl .
* Thu Oct  7 2004 max@suse.de
- New version: 1.7
* Tue Aug 17 2004 max@suse.de
- New version: 1.6.1
* Fri Feb 27 2004 max@suse.de
- Fixed path and name of tclsh in the examples.
* Mon Feb 16 2004 max@suse.de
- New version: 1.6.
* Mon May 12 2003 max@suse.de
- New version: 1.4.
* Mon Aug  5 2002 max@suse.de
- Copying man.macros into the manpages.
* Tue Jun 11 2002 max@suse.de
- New version 1.3
- Many new modules. See /usr/share/doc/packages/tcllib/ChangeLog
  for details.
* Wed Mar 13 2002 max@suse.de
- fixed the install script to also install the modules
  irc, doctools, and stats.
* Mon Jan 21 2002 max@suse.de
- added creation of install dirs
* Mon Jan 21 2002 max@suse.de
- new version: 1.2
- new modules: calendar, crc, doctools, irc, smtpd, and stooop.
* Mon Nov  5 2001 max@suse.de
- new version: 1.1
- new module: comm - remote communications facility
- new module: control - Procedures for control flow structures
* Thu Aug  2 2001 max@suse.de
- new package tcllib
- A script-only standard library for Tcl/Tk
